#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2011. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os.path, re
from java.lang import System

#------------------------------------------------------------------------------
# globals
#------------------------------------------------------------------------------
grantPattern = re.compile(r'grant\s+(?:codeBase\s+"([^"]+)"\s+)?\{')
permissionPattern = re.compile(r'\s*permission\s+([^;]+);')
closePattern = re.compile(r'\s*\};(\s*)')

#------------------------------------------------------------------------------
# log either to profile upgrade framework or to console, depending on context
#------------------------------------------------------------------------------
def log(level, method, message):
  if globals().has_key("framework"):
    framework.log(level, "upgradeBPMProfile.py", method, message)
  else:
    print message
#enddef

# -------------------------------------------------------------------------
# Update the server.policy file for the given profile with given permission
# -------------------------------------------------------------------------
def updateServerPolicyFile(profileRoot, comment, neededPermissions):
  serverPolicy = os.path.join(profileRoot, "properties/server.policy")
  log("info", "updateServerPolicyFile",  "Updating " + serverPolicy + ".")
  file = open(serverPolicy, "r")
  lines = file.readlines()
  file.close()
  # read first line and try to determine the line ending character used
  nl = System.getProperty("line.separator")
  if lines:
    newline = re.match(".*(\\s*)", lines[0])
    if newline:
      nl = newline.group(1)
  # patterns needed for parsing
  codeBase = None
  permissions = None
  # read server.policy file and make sure the existing grants contain the needed permissions
  file = open(serverPolicy, "w")
  for line in lines:
    grant = grantPattern.match(line)
    if grant:
      codeBase = grant.group(1)
      if neededPermissions.has_key(codeBase):
        permissions = neededPermissions[codeBase]
        log("info", "updateServerPolicyFile",  "  Found codeBase " + codeBase + ", looking for " + str(permissions))
      else:
        codeBase = None # none of interest, that is
        permissions = None
      #endif
    elif codeBase:
      close = closePattern.match(line)
      if close:
        if permissions:
          log("info", "updateServerPolicyFile",  "    Adding " + str(permissions))
        for permission in permissions:
          file.write('  permission ' + permission + ';' + nl)
        del neededPermissions[codeBase]
        codeBase = None
        permissions = None
      else:
        permission = permissionPattern.match(line).group(1)
        if permission in permissions:
          # log("info", "updateServerPolicyFile",  "    " + permission + " already granted")
          permissions.remove(permission)
      #endif
    #endif
    file.write(line)
  #endfor
  # add the new grant statements with their needed permissions
  codeBases = neededPermissions.keys()
  for codeBase in codeBases:
    permissions = neededPermissions[codeBase]
    log("info", "updateServerPolicyFile",  "  Adding codeBase " + codeBase + " with " + str(permissions))
    if comment:
      file.write('// ' + comment + nl)
      comment = None
    #endif
    file.write('grant codeBase "' + codeBase + '" {' + nl)
    for permission in permissions:
      file.write('  permission ' + permission + ';' + nl)
    file.write('};' + nl)
    file.write(nl)
  file.close()
#enddef

